@@ -22,6 +22,9 @@ class DataFrameSummary(object):
     TYPE_CONSTANT = 'constant'
     TYPE_UNIQUE = 'unique'
 
+    continuous=[]
+    categorical=[]
+
     def __init__(self, df, plot=False):
         self.df = df
         self.length = len(df)
@@ -59,8 +62,6 @@ class DataFrameSummary(object):
 
     def _get_pairplot(self,data):
         self.data=data
-        self.continuous=[]
-        self.categorical=[]
         for i in self.data.columns:
              if (self.data[i].nunique()/self.data.shape[0])*100 > 20 : ##unique nos in a column are more than 20% then it is a continuous variable
                 self.continuous.append(i)
